@@ -597,7 +597,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
     "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
     "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
-    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة.",
-    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح"
+    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
